.. image:: https://coveralls.io/repos/github/meatballs/blockbuster-core/badge.svg?branch=master
  :target: https://coveralls.io/github/meatballs/blockbuster-core?branch=master

.. image:: https://travis-ci.org/meatballs/blockbuster-core.svg?branch=master
  :target: https://travis-ci.org/meatballs/blockbuster-core

================
Blockbuster Core
================
A Python interface (API) to `todo.txt <https://github.com/todotxt/todo.txt>`_
files.

Introduction
------------
This library will form the basis for several todo list management applications.

It will provide the interface to the underlying todo.txt files and functions to
manage the tasks stored within those files.

Installation
------------
Sorry, there's nothing to install (yet)!

Usage
-----
It doesn't (yet) do anything at all!

FAQ
---

Why yet another todo manager?
*****************************
The todo.txt format is simple, available to anyone free of charge, mature,
stable, battle-tested and hardened.

However, many of the alternative, propietary tools offer features which the
todo.txt based tools do not. e.g. the use of mulitiple lists rather than just
one.

Also, many people, myself included, use a range of different tools across
multiple devices and these do not always offer the same range of features.

By placing the management functions in a core library, this project aims to
enable the creation of multiple client applications which have common features
and behaviour.

For example, the author intends to create a command line interface (similar to
the `original shell program <https://github.com/todotxt/todo.txt-cli>`_), a
textual interface (similar to `todotxt-machine <https://github.com/AnthonyDiGirolamo/todotxt-machine>`_
or `todd <https://github.com/laktak/todd>`_) and a mobile interface using `BeeWare <https://pybee.org/>`_.

Why call it Blockbuster?
************************
It's a reference to the `1973 chart topping hit <https://www.youtube.com/watch?v=Y64211sjSko>`_
by `The Sweet <https://en.wikipedia.org/wiki/The_Sweet>`_.

The song includes a line that was screamed incessantly by those of us on a UK
school playground that year to the constant irritation of our teachers:

  "We just haven't got a clue what to do!"
